# gstat_exporter
Prometheus exporter for FreeBSD gstat data

# Blog post
https://blog.tyk.nu/blog/all-in-a-days-work-prometheus-gstat_exporter-and-grafana-dashboard/

# Grafana Dashboard
https://grafana.com/grafana/dashboards/11223
